==> moodle_1.3.1.orig.tar.gz: moodle/lang/cs/resource.php <==
<?PHP // $Id: resource.php,v 1.2 2004/05/28 01:18:30 mudrd8mz Exp $ 
      // resource.php - created with Moodle 1.3 (2004052500)


$string['addresource'] = 'Pidat studijn materil';
$string['chooseafile'] = 'Vyberte nebo nahrejte soubor';
$string['configdefaulturl'] = 'Tato hodnota je pouita k vyplnn pedvolen hodnoty URL pi vytven novho URL zdroje.';
$string['configfilterexternalpages'] = 'Povolenm tohoto nastaven doclte toho, e i extern studijn materily (webov strnky, nahran HTML soubory) budou zpracovny stvajcmi aktivnmi filtry (napklad propojen se slovnkem). Zapnut tto volby me znateln zpomalit zobrazovn strnek kurz - proto ji pouvejte s opatrnost a jen v ppad, e ji opravdu potebujete.';
$string['configframesize'] = 'Jsoul-li Vloen webov strnka nebo Piloen soubor zobrazovny uvnit rmce, pak tato hodnota uruje velikost (v pixelech) nadazenho rmce (kter obsahuje navigan pruh).';
$string['configpopup'] = 'Kdy se pidv studijn materil, kter je mono zobrazit v novm okn, m bt tato monost implicitn povolena?';
$string['configpopupdirectories'] = 'Mly by se v novch oknech ukazovat v odkazu implicitn adrese?';
$string['configpopupheight'] = 'Vchoz vka novch oken';
$string['configpopuplocation'] = 'Ml by se v novch oknech implicitn zobrazovat pruh s umstnm (adresou)?';
$string['configpopupmenubar'] = 'Ml by se v novch oknech implicitn zobrazovat pruh s nabdkou (menu)?';
$string['configpopupresizable'] = 'Mla by se dt u novch oken implicitn mnit velikost?';
$string['configpopupscrollbars'] = 'Mlo by se dt v novch oknech implicitn skrolovat?';
$string['configpopupstatus'] = 'Ml by se v novch oknech implicitn zobrazovat stavov pruh?';
$string['configpopuptoolbar'] = 'Ml by se v novch oknech implicitn zobrazovat pruh s nstroji?';
$string['configpopupwidth'] = 'Vchoz ka novch oken';
$string['configwebsearch'] = 'Pokud pidvte vloenou strnku nebo odkaz, je tato adresa nabdnuta jako strnka, kde me uivatel najt poadovan URL.';
$string['directlink'] = 'Pm odkaz na tento soubor';
$string['directoryinfo'] = 'Budou zobrazeny vechny soubory ve zvolenm adresi.';
$string['editingaresource'] = 'prava studijnho materilu';
$string['example'] = 'Pklad';
$string['examplereference'] = 'BLACKMOREOV, S. <i>Teorie mem : kultura a jej evoluce.</i> Vyd. 1. Praha : Portl, 2001. 236 s. ISBN 80-7178-394-3.';
$string['exampleurl'] = 'http://www.napriklad.zde/adresar/soubor.html';
$string['fetchclienterror'] = 'Pi pokusu o zskn webov strnky dolo u vaeho prohlee k chyb (teba patn URL).';
$string['fetcherror'] = 'Pi pokusu o zskn webov strnky dolo k chyb.';
$string['fetchservererror'] = 'Pi pokusu o zskn webov strnky dolo u vzdlenho serveru k chyb (pravdpodobn chyba programu).</p>';
$string['filename'] = 'Jmno souboru';
$string['filtername'] = 'Automatick propojovn materilu';
$string['fulltext'] = 'Full text';
$string['htmlfragment'] = 'HTML fragment';
$string['maindirectory'] = 'Adres s hlavnmi soubory';
$string['modulename'] = 'Studijn materil';
$string['modulenameplural'] = 'Studijn materily';
$string['neverseen'] = 'Neprohleno';
$string['newdirectories'] = 'Ukazovat adres v odkazu';
$string['newfullscreen'] = 'Zaplnit celou obrazovku';
$string['newheight'] = 'Vchoz vka okna (v pixelech)';
$string['newlocation'] = 'Ukazovat pruh s adresou';
$string['newmenubar'] = 'Ukazovat pruh s nabdkou';
$string['newresizable'] = 'Povolit zmnu velikosti okna';
$string['newscrollbars'] = 'Povolit skrolovn okna';
$string['newstatus'] = 'Ukazovat stavov pruh';
$string['newtoolbar'] = 'Ukazovat pruh s nstroji';
$string['newwidth'] = 'Vchoz ka okna (v pixelech)';
$string['newwindow'] = 'Nov okno';
$string['newwindowopen'] = 'Zobrazovat tento studijn materil v novm okn';
$string['note'] = 'Poznmka';
$string['notefile'] = 'K nahrn dalch soubor do tohoto kurzu (aby se ukazovaly v tomto seznamu) pouijte <A HREF=$a >Sprvce soubor</A>.';
$string['notypechosen'] = 'Muste vybrat typ. Vrate se pomoc tlatka \'Zpt\' a zkuste to znovu.';
$string['popupresource'] = 'Tento studijn materil by se ml zobrazovat v novm okn';
$string['popupresourcelink'] = 'Pokud se tak nestalo, kliknte zde: $a';
$string['resourcetype'] = 'Typ studijnho materilu';
$string['resourcetype1'] = 'Literatura';
$string['resourcetype2'] = 'Vloen webov strnka';
$string['resourcetype3'] = 'Soubor';
$string['resourcetype4'] = 'ist text';
$string['resourcetype5'] = 'Odkaz';
$string['resourcetype6'] = 'HTML text';
$string['resourcetype7'] = 'Program';
$string['resourcetype8'] = 'Wiki text';
$string['resourcetype9'] = 'Adres';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/cs/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.4 (2004083100)


$string['addresource'] = 'Pidat studijn materil';
$string['chooseafile'] = 'Vyberte nebo nahrejte soubor';
$string['chooseparameter'] = 'Vyberte parametr';
$string['configdefaulturl'] = 'Tato hodnota je pouita k vyplnn pedvolen hodnoty URL pi vytven novho URL zdroje.';
$string['configfilterexternalpages'] = 'Povolenm tohoto nastaven doclte toho, e i extern studijn materily (webov strnky, nahran HTML soubory) budou zpracovny stvajcmi aktivnmi filtry (napklad propojen se slovnkem). Zapnut tto volby me znateln zpomalit zobrazovn strnek kurz - proto ji pouvejte s opatrnost a jen v ppad, e ji opravdu potebujete.';
$string['configframesize'] = 'Jsou-li Vloen webov strnka nebo Piloen soubor zobrazovny uvnit rmce, pak tato hodnota uruje velikost (v pixelech) nadazenho rmce (kter obsahuje navigan pruh).';
$string['configparametersettings'] = 'Tmto se nastavuje vchoz nastaven panelu Parametry ve formuli pro pidn novho studijnho materilu. Po prvnm pouit se tyto hodnoty stvaj soust preferenc jednotlivch uivatel.';
$string['configpopup'] = 'Kdy se pidv studijn materil, kter je mono zobrazit v novm okn, m bt tato monost implicitn povolena?';
$string['configpopupdirectories'] = 'Mly by se v novch oknech ukazovat v odkazu implicitn adrese?';
$string['configpopupheight'] = 'Vchoz vka novch oken';
$string['configpopuplocation'] = 'Ml by se v novch oknech implicitn zobrazovat pruh s umstnm (adresou)?';
$string['configpopupmenubar'] = 'Ml by se v novch oknech implicitn zobrazovat pruh s nabdkou (menu)?';
$string['configpopupresizable'] = 'Mla by se dt u novch oken implicitn mnit velikost?';
$string['configpopupscrollbars'] = 'Mlo by se dt v novch oknech implicitn skrolovat?';
$string['configpopupstatus'] = 'Ml by se v novch oknech implicitn zobrazovat stavov pruh?';
$string['configpopuptoolbar'] = 'Ml by se v novch oknech implicitn zobrazovat pruh s nstroji?';
$string['configpopupwidth'] = 'Vchoz ka novch oken';
$string['configsecretphrase'] = 'Tento tajn vraz se pouv k tvorb ifrovanho kdu, kter mete zaslat nkterm externm zdrojm studijnch materil (jako nap. vae vlastn skripty) jako parametr. ifrovan kd je vytvoen jako MD5 hodnota IP adresy stvajcho uivatele (current_user) spojen s vam tajnm vrazem, tzn. kod=md5(IP.tajnyvyraz) . To umouje externm zdrojm ovovat oprvnnost spojen.';
$string['configwebsearch'] = 'Pokud pidvte vloenou strnku nebo odkaz, je tato adresa nabdnuta jako strnka, kde me uivatel najt poadovan URL.';
$string['configwindowsettings'] = 'Tmto se nastavuje vchoz nastaven panelu Okno ve formuli pro pidn novho studijnho materilu. Po prvnm pouit se tyto hodnoty stvaj soust preferenc jednotlivch uivatel.';
$string['directlink'] = 'Pm odkaz na tento soubor';
$string['directoryinfo'] = 'Budou zobrazeny vechny soubory ve zvolenm adresi.';
$string['display'] = 'Okno';
$string['editingaresource'] = 'prava studijnho materilu';
$string['encryptedcode'] = 'ifrovan kd';
$string['example'] = 'Pklad';
$string['exampleurl'] = 'http://www.napriklad.zde/adresar/soubor.html';
$string['fetchclienterror'] = 'Pi pokusu o zskn webov strnky dolo u vaeho prohlee k chyb (teba patn URL).';
$string['fetcherror'] = 'Pi pokusu o zskn webov strnky dolo k chyb.';
$string['fetchservererror'] = 'Pi pokusu o zskn webov strnky dolo u vzdlenho serveru k chyb (pravdpodobn chyba programu).</p>';
$string['filename'] = 'Jmno souboru';
$string['filtername'] = 'Automatick propojovn materilu';
$string['frameifpossible'] = 'Umstit studijn materil do rmce a ponechat tak na obrazovce navigan litu';
$string['fulltext'] = 'Full text';
$string['htmlfragment'] = 'HTML fragment';
$string['maindirectory'] = 'Adres s hlavnmi soubory';
$string['modulename'] = 'Studijn materil';
$string['modulenameplural'] = 'Studijn materily';
$string['neverseen'] = 'Neprohleno';
$string['newdirectories'] = 'Ukazovat adres v odkazu';
$string['newfullscreen'] = 'Zaplnit celou obrazovku';
$string['newheight'] = 'Vchoz vka okna (v pixelech)';
$string['newlocation'] = 'Ukazovat pruh s adresou';
$string['newmenubar'] = 'Ukazovat pruh s nabdkou';
$string['newresizable'] = 'Povolit zmnu velikosti okna';
$string['newscrollbars'] = 'Povolit skrolovn okna';
$string['newstatus'] = 'Ukazovat stavov pruh';
$string['newtoolbar'] = 'Ukazovat pruh s nstroji';
$string['newwidth'] = 'Vchoz ka okna (v pixelech)';
$string['newwindow'] = 'Nov okno';
$string['newwindowopen'] = 'Zobrazovat tento studijn materil v novm okn';
$string['note'] = 'Poznmka';
$string['notefile'] = 'K nahrn dalch soubor do tohoto kurzu (aby se ukazovaly v tomto seznamu) pouijte <A HREF=$a >Sprvce soubor</A>.';
$string['notypechosen'] = 'Muste vybrat typ. Vrate se pomoc tlatka \'Zpt\' a zkuste to znovu.';
$string['pagedisplay'] = 'Zobrazovat tento materil ve stvajcm okn';
$string['pagewindow'] = 'Stejn okno';
$string['parameter'] = 'Parametr';
$string['parameters'] = 'Parametry';
$string['popupresource'] = 'Tento studijn materil by se ml zobrazovat v novm okn';
$string['popupresourcelink'] = 'Pokud se tak nestalo, kliknte zde: $a';
$string['resourcetype'] = 'Typ studijnho materilu';
$string['resourcetype1'] = 'Literatura';
$string['resourcetype2'] = 'Vloen webov strnka';
$string['resourcetype3'] = 'Soubor';
$string['resourcetype4'] = 'ist text';
$string['resourcetype5'] = 'Odkaz';
$string['resourcetype6'] = 'HTML text';
$string['resourcetype7'] = 'Program';
$string['resourcetype8'] = 'Wiki text';
$string['resourcetype9'] = 'Adres';
$string['resourcetypedirectory'] = 'Zobrazit adres';
$string['resourcetypefile'] = 'Odkaz na soubor/web';
$string['resourcetypehtml'] = 'Vytvoit webovou strnku';
$string['resourcetypelabel'] = 'Vytvoit popisek';
$string['resourcetypetext'] = 'Vytvoit strnku s textem';
$string['searchweb'] = 'Hledat webovou strnku';
$string['variablename'] = 'Nzev promnn';

?>
